Enum apocalypse::Error[][src]

pub enum Error {
    TokioSend(String),
    IO(Error),
    WrongType,
    InvalidLocation,
    Unimplemented,
}
Errors thrown by this library

Variants

TokioSend(String)

Error when using either oneshot or mpsc channels

Tuple Fields of TokioSend

0: String
IO(Error)

IO errors (for example, tcp errors)

Tuple Fields of IO

0: Error
WrongType

In theory, impossible error for Any to Input and Any to Output conversion

InvalidLocation

Indicates that there is no such demon with this location

Unimplemented

Needs to be removed